ardt.datasets.ascertain.AscertainTrial
======================================

.. currentmodule:: ardt.datasets.ascertain

.. autoclass:: AscertainTrial

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AscertainTrial.__init__
      ~AscertainTrial.get_signal_metadata
      ~AscertainTrial.load_ground_truth
      ~AscertainTrial.load_preprocessed_signal_data
      ~AscertainTrial.load_signal_data
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AscertainTrial.dataset
      ~AscertainTrial.expected_response
      ~AscertainTrial.media_id
      ~AscertainTrial.media_name
      ~AscertainTrial.participant_id
      ~AscertainTrial.signal_data_files
      ~AscertainTrial.signal_preprocessors
      ~AscertainTrial.signal_types
   
   